autowisp.tests.test_detrending_stat module — AutoWISP documentation

# autowisp.tests.test_detrending_stat module

## Class Inheritance Diagram

Define Testt class for the EPD and TFA statistics genaration.

class autowisp.tests.test_detrending_stat.TestDetrendingStat(methodName='runTest')

  Bases: `AutoWISPTestCase`

  Tests for the generate_(epd/tfa)_statistics steps.

  run_test(mode)

    Run the test for the given detrending mode (“epd” or “tfa”).

  test_generate_epd_statistics()

    Test the generation of EPD statistics.

  test_generate_tfa_statistics()

    Test the generation of TFA statistics.